const char *authors =
"Maintainers\n"
"-------\n"
"Fredrik Arnerup		<arnerup@kth.se>\n"
"Rasmus Kaj		<kaj@e.kth.se>\n"
"\n"
"Contributors\n"
"------------\n"
"Sergej Gratchev		- prefs dialog, gui work\n"
"Ayose Cazorla León	- threading bugfix\n"
"Gaudenz Steinlin	- man pages\n"
"Magnus Henoch		- postscript landscape mode bugfix\n"
"Emissionen		- being guinea pigs :-)\n"
;
